'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

exports.default = function (babel) {
  var t = babel.types;

  var attrVisitor = {
    JSXAttribute: function JSXAttribute(path) {
      if (t.isJSXNamespacedName(path.node.name)) {
        path.node.name = t.jSXIdentifier(namespaceToCamel(path.node.name.namespace.name, path.node.name.name.name));
      } else if (t.isJSXIdentifier(path.node.name)) {
        if (path.node.name.name === 'class') {
          path.node.name.name = "className";
        }

        if (path.node.name.name === 'style') {
          var csso = cssToObj(path.node.value.value);
          var properties = (0, _keys2.default)(csso).map(function (prop) {
            return t.objectProperty(t.identifier(hyphenToCamel(prop)), t.stringLiteral(csso[prop]));
          });
          path.node.value = t.jSXExpressionContainer(t.objectExpression(properties));
        }

        if (path.node.name.name.indexOf('data-') !== 0) {
          path.node.name.name = hyphenToCamel(path.node.name.name);
        }
      }
    }
  };

  var getExport = function getExport(svg) {
    var className = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'SVG';

    return t.exportDefaultDeclaration(t.classDeclaration(t.identifier(className), t.memberExpression(t.identifier('React'), t.identifier('Component')), t.classBody([t.classMethod('method', t.identifier('render'), [], t.blockStatement([t.returnStatement(svg)]))]), []));
  };

  var svgVisitor = {
    JSXOpeningElement: function JSXOpeningElement(path) {
      if (path.node.name.name.toLowerCase() === 'svg') {
        path.node.attributes.push(t.jSXSpreadAttribute(t.memberExpression(t.thisExpression(), t.identifier('props'))));
      }
    }
  };

  var svgExpressionVisitor = {
    ExpressionStatement: function ExpressionStatement(path) {
      if (!path.get('expression').isJSXElement()) return;
      if (path.get('expression.openingElement.name').node.name !== 'svg') return;
      path.replaceWith(getExport(path.get('expression').node));
    }
  };

  var programVisitor = {
    Program: function Program(path) {
      path.node.body.unshift(t.importDeclaration([t.importDefaultSpecifier(t.identifier('React'))], t.stringLiteral('react')));
    }
  };

  return {
    visitor: (0, _extends3.default)({}, programVisitor, svgExpressionVisitor, svgVisitor, attrVisitor)
  };
};

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function cssToObj(css) {
  var o = {};
  var elements = css.split(';');
  elements.filter(function (el) {
    return !!el;
  }).forEach(function (el) {
    var s = el.split(':'),
        key = s.shift().trim(),
        value = s.join(':').trim();
    o[key] = value;
  });
  return o;
}

function hyphenToCamel(name) {
  return name.replace(/-([a-z])/g, function (g) {
    return g[1].toUpperCase();
  });
}

function namespaceToCamel(namespace, name) {
  return namespace + name.charAt(0).toUpperCase() + name.slice(1);
}

module.exports = exports['default'];